# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/opensearch/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.mdb.opensearch.v1 import auth_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_auth__pb2
from yandex.cloud.mdb.opensearch.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.opensearch.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.opensearch.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/opensearch/v1/cluster_service.proto',
  package='yandex.cloud.mdb.opensearch.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4yandex/cloud/mdb/opensearch/v1/cluster_service.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a)yandex/cloud/mdb/opensearch/v1/auth.proto\x1a,yandex/cloud/mdb/opensearch/v1/cluster.proto\x1a+yandex/cloud/mdb/opensearch/v1/backup.proto\x1a\x30yandex/cloud/mdb/opensearch/v1/maintenance.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.opensearch.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa5\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.opensearch.v1.Cluster.Environment\x12K\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.ConfigCreateSpecB\x04\xe8\xc7\x31\x01\x12 \n\nnetwork_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12M\n\x12maintenance_window\x18\x0b \x01(\x0b\x32\x31.yandex.cloud.mdb.opensearch.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xe1\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x45\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12M\n\x12maintenance_window\x18\n \x01(\x0b\x32\x31.yandex.cloud.mdb.opensearch.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xce\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x05 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x07 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\x08 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12X\n\x0cservice_type\x18\t \x01(\x0e\x32\x42.yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.ServiceType\"K\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nOPENSEARCH\x10\x01\x12\x0e\n\nDASHBOARDS\x10\x02\"\xb3\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x07message\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.mdb.opensearch.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x17ListClusterLogsResponse\x12\x37\n\x04logs\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.opensearch.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x0fStreamLogRecord\x12\x39\n\x06record\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\x95\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12Z\n\x0cservice_type\x18\x07 \x01(\x0e\x32\x44.yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.ServiceType\"K\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nOPENSEARCH\x10\x01\x12\x0e\n\nDASHBOARDS\x10\x02\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x18ListClusterHostsResponse\x12\x33\n\x05hosts\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.opensearch.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x97\x02\n\x10\x43onfigCreateSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1c\n\x0e\x61\x64min_password\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12M\n\x0fopensearch_spec\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec\x12M\n\x0f\x64\x61shboards_spec\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32&.yandex.cloud.mdb.opensearch.v1.Access\"\xbd\x03\n\x14OpenSearchCreateSpec\x12\x0f\n\x07plugins\x18\x01 \x03(\t\x12S\n\x0bnode_groups\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup\x1a\xbe\x02\n\tNodeGroup\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x1c\n\x0bhosts_count\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\"\n\x08zone_ids\x18\x04 \x03(\tB\x10\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\x12$\n\nsubnet_ids\x18\x05 \x03(\tB\x10\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\x12\x43\n\x05roles\x18\x07 \x03(\x0e\x32\x34.yandex.cloud.mdb.opensearch.v1.OpenSearch.GroupRole\"\xd5\x02\n\x14\x44\x61shboardsCreateSpec\x12S\n\x0bnode_groups\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup\x1a\xe7\x01\n\tNodeGroup\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x1c\n\x0bhosts_count\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x10\n\x08zone_ids\x18\x04 \x03(\t\x12$\n\nsubnet_ids\x18\x05 \x03(\tB\x10\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\"\xa5\x02\n\x10\x43onfigUpdateSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1c\n\x0e\x61\x64min_password\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12T\n\x0fopensearch_spec\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.opensearch.v1.OpenSearchClusterUpdateSpec\x12T\n\x0f\x64\x61shboards_spec\x18\x04 \x01(\x0b\x32;.yandex.cloud.mdb.opensearch.v1.DashboardsClusterUpdateSpec\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32&.yandex.cloud.mdb.opensearch.v1.Access\".\n\x1bOpenSearchClusterUpdateSpec\x12\x0f\n\x07plugins\x18\x01 \x03(\t\"\x1d\n\x1b\x44\x61shboardsClusterUpdateSpec\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xc0\x05\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x92\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x41.yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.opensearch.v1.Cluster.Environment\x12K\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.ConfigCreateSpecB\x04\xe8\xc7\x31\x01\x12 \n\nnetwork_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12\x1f\n\tfolder_id\x18\x0b \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12M\n\x12maintenance_window\x18\x0c \x01(\x0b\x32\x31.yandex.cloud.mdb.opensearch.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xcf\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12j\n\x0freschedule_type\x18\x02 \x01(\x0e\x32K.yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"f\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1aListClusterBackupsResponse\x12\x37\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.opensearch.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"R\n DeleteOpenSearchNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xfb\x01\n UpdateOpenSearchNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12V\n\x0fnode_group_spec\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec\"\xb7\x01\n\x1dOpenSearchNodeGroupUpdateSpec\x12<\n\tresources\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x13\n\x0bhosts_count\x18\x02 \x01(\x03\x12\x43\n\x05roles\x18\x03 \x03(\x0e\x32\x34.yandex.cloud.mdb.opensearch.v1.OpenSearch.GroupRole\"\x9a\x01\n\x1d\x41\x64\x64OpenSearchNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0fnode_group_spec\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup\"r\n DeleteDashboardsNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"\xfb\x01\n UpdateDashboardsNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12V\n\x0fnode_group_spec\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.opensearch.v1.DashboardsNodeGroupUpdateSpec\"r\n\x1d\x44\x61shboardsNodeGroupUpdateSpec\x12<\n\tresources\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x13\n\x0bhosts_count\x18\x02 \x01(\x03\"\x9a\x01\n\x1d\x41\x64\x64\x44\x61shboardsNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0fnode_group_spec\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup\"8\n\x14\x41\x64\x64NodeGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\";\n\x17UpdateNodeGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\";\n\x17\x44\x65leteNodeGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x16GetAuthSettingsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"}\n\x19UpdateAuthSettingsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08settings\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.opensearch.v1.AuthSettings\"0\n\x1aUpdateAuthSettingsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t2\xd2\'\n\x0e\x43lusterService\x12\x97\x01\n\x03Get\x12\x31.yandex.cloud.mdb.opensearch.v1.GetClusterRequest\x1a\'.yandex.cloud.mdb.opensearch.v1.Cluster\"4\x82\xd3\xe4\x93\x02.\x12,/managed-opensearch/v1/clusters/{cluster_id}\x12\x9a\x01\n\x04List\x12\x33.yandex.cloud.mdb.opensearch.v1.ListClustersRequest\x1a\x34.yandex.cloud.mdb.opensearch.v1.ListClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-opensearch/v1/clusters\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.opensearch.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"N\x82\xd3\xe4\x93\x02$\"\x1f/managed-opensearch/v1/clusters:\x01*\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x12\xbe\x01\n\x06Update\x12\x34.yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02\x31\x32,/managed-opensearch/v1/clusters/{cluster_id}:\x01*\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.opensearch.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"f\x82\xd3\xe4\x93\x02.*,/managed-opensearch/v1/clusters/{cluster_id}\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x12\xc2\x01\n\x06\x42\x61\x63kup\x12\x34.yandex.cloud.mdb.opensearch.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"_\x82\xd3\xe4\x93\x02\x35\"3/managed-opensearch/v1/clusters/{cluster_id}:backup\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x12\xbc\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"W\x82\xd3\xe4\x93\x02,\"\'/managed-opensearch/v1/clusters:restore:\x01*\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x12\xf3\x01\n\x15RescheduleMaintenance\x12<.yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"y\x82\xd3\xe4\x93\x02G\"B/managed-opensearch/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x12\xc2\x01\n\x0bListBackups\x12\x39.yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest\x1a:.yandex.cloud.mdb.opensearch.v1.ListClusterBackupsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-opensearch/v1/clusters/{cluster_id}/backups\x12\xbd\x01\n\x04Move\x12\x32.yandex.cloud.mdb.opensearch.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02\x36\"1/managed-opensearch/v1/clusters/{cluster_id}:move:\x01*\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x12\xbe\x01\n\x05Start\x12\x33.yandex.cloud.mdb.opensearch.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\x82\xd3\xe4\x93\x02\x34\"2/managed-opensearch/v1/clusters/{cluster_id}:start\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x12\xba\x01\n\x04Stop\x12\x32.yandex.cloud.mdb.opensearch.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02\x33\"1/managed-opensearch/v1/clusters/{cluster_id}:stop\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x12\xb6\x01\n\x08ListLogs\x12\x36.yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest\x1a\x37.yandex.cloud.mdb.opensearch.v1.ListClusterLogsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-opensearch/v1/clusters/{cluster_id}:logs\x12\xbb\x01\n\nStreamLogs\x12\x38.yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest\x1a/.yandex.cloud.mdb.opensearch.v1.StreamLogRecord\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-opensearch/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xce\x01\n\x0eListOperations\x12<.yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest\x1a=.yandex.cloud.mdb.opensearch.v1.ListClusterOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-opensearch/v1/clusters/{cluster_id}/operations\x12\xba\x01\n\tListHosts\x12\x37.yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest\x1a\x38.yandex.cloud.mdb.opensearch.v1.ListClusterHostsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-opensearch/v1/clusters/{cluster_id}/hosts\x12\xfb\x01\n\x16\x41\x64\x64OpenSearchNodeGroup\x12=.yandex.cloud.mdb.opensearch.v1.AddOpenSearchNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x82\xd3\xe4\x93\x02H\"C/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups:\x01*\xb2\xd2*-\n\x14\x41\x64\x64NodeGroupMetadata\x12\x15google.protobuf.Empty\x12\x89\x02\n\x19\x44\x65leteOpenSearchNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.DeleteOpenSearchNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\x82\xd3\xe4\x93\x02L*J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x12\x8c\x02\n\x19UpdateOpenSearchNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\x82\xd3\xe4\x93\x02O2J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}:\x01*\xb2\xd2*0\n\x17UpdateNodeGroupMetadata\x12\x15google.protobuf.Empty\x12\xfb\x01\n\x16\x41\x64\x64\x44\x61shboardsNodeGroup\x12=.yandex.cloud.mdb.opensearch.v1.AddDashboardsNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x82\xd3\xe4\x93\x02H\"C/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups:\x01*\xb2\xd2*-\n\x14\x41\x64\x64NodeGroupMetadata\x12\x15google.protobuf.Empty\x12\x89\x02\n\x19\x44\x65leteDashboardsNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.DeleteDashboardsNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\x82\xd3\xe4\x93\x02L*J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x12\x8c\x02\n\x19UpdateDashboardsNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\x82\xd3\xe4\x93\x02O2J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}:\x01*\xb2\xd2*0\n\x17UpdateNodeGroupMetadata\x12\x15google.protobuf.Empty\x12\xb2\x01\n\x0fGetAuthSettings\x12\x36.yandex.cloud.mdb.opensearch.v1.GetAuthSettingsRequest\x1a,.yandex.cloud.mdb.opensearch.v1.AuthSettings\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-opensearch/v1/clusters/{cluster_id}/auth\x12\xde\x01\n\x12UpdateAuthSettings\x12\x39.yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsRequest\x1a!.yandex.cloud.operation.Operation\"j\x82\xd3\xe4\x93\x02\x36\x1a\x31/managed-opensearch/v1/clusters/{cluster_id}/auth:\x01*\xb2\xd2**\n\x1aUpdateAuthSettingsMetadata\x12\x0c\x41uthSettingsBs\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_auth__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_maintenance__pb2.DESCRIPTOR,])



_LISTCLUSTERLOGSREQUEST_SERVICETYPE = _descriptor.EnumDescriptor(
  name='ServiceType',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.ServiceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVICE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPENSEARCH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASHBOARDS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2657,
  serialized_end=2732,
)
_sym_db.RegisterEnumDescriptor(_LISTCLUSTERLOGSREQUEST_SERVICETYPE)

_STREAMCLUSTERLOGSREQUEST_SERVICETYPE = _descriptor.EnumDescriptor(
  name='ServiceType',
  full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.ServiceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVICE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPENSEARCH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DASHBOARDS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2657,
  serialized_end=2732,
)
_sym_db.RegisterEnumDescriptor(_STREAMCLUSTERLOGSREQUEST_SERVICETYPE)

_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE = _descriptor.EnumDescriptor(
  name='RescheduleType',
  full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest.RescheduleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESCHEDULE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEXT_AVAILABLE_WINDOW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPECIFIC_TIME', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6959,
  serialized_end=7069,
)
_sym_db.RegisterEnumDescriptor(_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE)


_GETCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.GetClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.GetClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=527,
)


_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListClustersRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.mdb.opensearch.v1.ListClustersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.opensearch.v1.ListClustersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.mdb.opensearch.v1.ListClustersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=674,
)


_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListClustersResponse',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='yandex.cloud.mdb.opensearch.v1.ListClustersResponse.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=782,
)


_CREATECLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1462,
)

_CREATECLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.environment', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_spec', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.config_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.network_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.security_group_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.service_account_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.deletion_protection', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_window', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.maintenance_window', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=1462,
)


_CREATECLUSTERMETADATA = _descriptor.Descriptor(
  name='CreateClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.CreateClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1464,
  serialized_end=1507,
)


_UPDATECLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1462,
)

_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_spec', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.config_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.security_group_ids', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.service_account_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.deletion_protection', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_window', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.maintenance_window', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1510,
  serialized_end=2119,
)


_UPDATECLUSTERMETADATA = _descriptor.Descriptor(
  name='UpdateClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2164,
)


_DELETECLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.DeleteClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.DeleteClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2166,
  serialized_end=2222,
)


_DELETECLUSTERMETADATA = _descriptor.Descriptor(
  name='DeleteClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.DeleteClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.DeleteClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2224,
  serialized_end=2267,
)


_LISTCLUSTERLOGSREQUEST = _descriptor.Descriptor(
  name='ListClusterLogsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_filter', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.column_filter', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.from_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_time', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.to_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.page_size', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.page_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_next_page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.always_next_page_token', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.filter', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_type', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.service_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LISTCLUSTERLOGSREQUEST_SERVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2270,
  serialized_end=2732,
)


_LOGRECORD_MESSAGEENTRY = _descriptor.Descriptor(
  name='MessageEntry',
  full_name='yandex.cloud.mdb.opensearch.v1.LogRecord.MessageEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.opensearch.v1.LogRecord.MessageEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.opensearch.v1.LogRecord.MessageEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2868,
  serialized_end=2914,
)

_LOGRECORD = _descriptor.Descriptor(
  name='LogRecord',
  full_name='yandex.cloud.mdb.opensearch.v1.LogRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='yandex.cloud.mdb.opensearch.v1.LogRecord.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='yandex.cloud.mdb.opensearch.v1.LogRecord.message', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGRECORD_MESSAGEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2735,
  serialized_end=2914,
)


_LISTCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
  name='ListClusterLogsResponse',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsResponse.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterLogsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2916,
  serialized_end=3023,
)


_STREAMLOGRECORD = _descriptor.Descriptor(
  name='StreamLogRecord',
  full_name='yandex.cloud.mdb.opensearch.v1.StreamLogRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='yandex.cloud.mdb.opensearch.v1.StreamLogRecord.record', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_record_token', full_name='yandex.cloud.mdb.opensearch.v1.StreamLogRecord.next_record_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3025,
  serialized_end=3128,
)


_STREAMCLUSTERLOGSREQUEST = _descriptor.Descriptor(
  name='StreamClusterLogsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_filter', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.column_filter', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.from_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_time', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.to_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record_token', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.record_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.filter', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_type', full_name='yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.service_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMCLUSTERLOGSREQUEST_SERVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3131,
  serialized_end=3536,
)


_LISTCLUSTEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListClusterOperationsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3538,
  serialized_end=3664,
)


_LISTCLUSTEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListClusterOperationsResponse',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3666,
  serialized_end=3777,
)


_LISTCLUSTERHOSTSREQUEST = _descriptor.Descriptor(
  name='ListClusterHostsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3779,
  serialized_end=3900,
)


_LISTCLUSTERHOSTSRESPONSE = _descriptor.Descriptor(
  name='ListClusterHostsResponse',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsResponse.hosts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterHostsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3902,
  serialized_end=4006,
)


_MOVECLUSTERREQUEST = _descriptor.Descriptor(
  name='MoveClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4008,
  serialized_end=4107,
)


_MOVECLUSTERMETADATA = _descriptor.Descriptor(
  name='MoveClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_folder_id', full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterMetadata.source_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.mdb.opensearch.v1.MoveClusterMetadata.destination_folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4109,
  serialized_end=4207,
)


_STARTCLUSTERREQUEST = _descriptor.Descriptor(
  name='StartClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.StartClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.StartClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4209,
  serialized_end=4264,
)


_STARTCLUSTERMETADATA = _descriptor.Descriptor(
  name='StartClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.StartClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.StartClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4266,
  serialized_end=4308,
)


_STOPCLUSTERREQUEST = _descriptor.Descriptor(
  name='StopClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.StopClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.StopClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4310,
  serialized_end=4364,
)


_STOPCLUSTERMETADATA = _descriptor.Descriptor(
  name='StopClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.StopClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.StopClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4366,
  serialized_end=4407,
)


_CONFIGCREATESPEC = _descriptor.Descriptor(
  name='ConfigCreateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_password', full_name='yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec.admin_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opensearch_spec', full_name='yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec.opensearch_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dashboards_spec', full_name='yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec.dashboards_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access', full_name='yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec.access', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4410,
  serialized_end=4689,
)


_OPENSEARCHCREATESPEC_NODEGROUP = _descriptor.Descriptor(
  name='NodeGroup',
  full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.hosts_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_ids', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.zone_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.subnet_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ip', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.assign_public_ip', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup.roles', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4819,
  serialized_end=5137,
)

_OPENSEARCHCREATESPEC = _descriptor.Descriptor(
  name='OpenSearchCreateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugins', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.plugins', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_groups', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.node_groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OPENSEARCHCREATESPEC_NODEGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4692,
  serialized_end=5137,
)


_DASHBOARDSCREATESPEC_NODEGROUP = _descriptor.Descriptor(
  name='NodeGroup',
  full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup.hosts_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_ids', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup.zone_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup.subnet_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ip', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup.assign_public_ip', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5250,
  serialized_end=5481,
)

_DASHBOARDSCREATESPEC = _descriptor.Descriptor(
  name='DashboardsCreateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_groups', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.node_groups', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DASHBOARDSCREATESPEC_NODEGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5140,
  serialized_end=5481,
)


_CONFIGUPDATESPEC = _descriptor.Descriptor(
  name='ConfigUpdateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_password', full_name='yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec.admin_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opensearch_spec', full_name='yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec.opensearch_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dashboards_spec', full_name='yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec.dashboards_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access', full_name='yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec.access', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5484,
  serialized_end=5777,
)


_OPENSEARCHCLUSTERUPDATESPEC = _descriptor.Descriptor(
  name='OpenSearchClusterUpdateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchClusterUpdateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugins', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchClusterUpdateSpec.plugins', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5779,
  serialized_end=5825,
)


_DASHBOARDSCLUSTERUPDATESPEC = _descriptor.Descriptor(
  name='DashboardsClusterUpdateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.DashboardsClusterUpdateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5827,
  serialized_end=5856,
)


_BACKUPCLUSTERREQUEST = _descriptor.Descriptor(
  name='BackupClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.BackupClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.BackupClusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5858,
  serialized_end=5914,
)


_BACKUPCLUSTERMETADATA = _descriptor.Descriptor(
  name='BackupClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.BackupClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.BackupClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5916,
  serialized_end=5959,
)


_RESTORECLUSTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1462,
)

_RESTORECLUSTERREQUEST = _descriptor.Descriptor(
  name='RestoreClusterRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.backup_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.environment', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_spec', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.config_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.network_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.security_group_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.service_account_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.deletion_protection', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.folder_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_window', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.maintenance_window', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESTORECLUSTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5962,
  serialized_end=6666,
)


_RESTORECLUSTERMETADATA = _descriptor.Descriptor(
  name='RestoreClusterMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.mdb.opensearch.v1.RestoreClusterMetadata.backup_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6668,
  serialized_end=6731,
)


_RESCHEDULEMAINTENANCEREQUEST = _descriptor.Descriptor(
  name='RescheduleMaintenanceRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reschedule_type', full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest.reschedule_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_until', full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest.delayed_until', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6734,
  serialized_end=7069,
)


_RESCHEDULEMAINTENANCEMETADATA = _descriptor.Descriptor(
  name='RescheduleMaintenanceMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_until', full_name='yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceMetadata.delayed_until', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7071,
  serialized_end=7173,
)


_LISTCLUSTERBACKUPSREQUEST = _descriptor.Descriptor(
  name='ListClusterBackupsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7175,
  serialized_end=7298,
)


_LISTCLUSTERBACKUPSRESPONSE = _descriptor.Descriptor(
  name='ListClusterBackupsResponse',
  full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backups', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsResponse.backups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.opensearch.v1.ListClusterBackupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7300,
  serialized_end=7410,
)


_DELETEOPENSEARCHNODEGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteOpenSearchNodeGroupRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.DeleteOpenSearchNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.DeleteOpenSearchNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.DeleteOpenSearchNodeGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7412,
  serialized_end=7494,
)


_UPDATEOPENSEARCHNODEGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateOpenSearchNodeGroupRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_group_spec', full_name='yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest.node_group_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7497,
  serialized_end=7748,
)


_OPENSEARCHNODEGROUPUPDATESPEC = _descriptor.Descriptor(
  name='OpenSearchNodeGroupUpdateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec.hosts_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec.roles', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7751,
  serialized_end=7934,
)


_ADDOPENSEARCHNODEGROUPREQUEST = _descriptor.Descriptor(
  name='AddOpenSearchNodeGroupRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.AddOpenSearchNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.AddOpenSearchNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_group_spec', full_name='yandex.cloud.mdb.opensearch.v1.AddOpenSearchNodeGroupRequest.node_group_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7937,
  serialized_end=8091,
)


_DELETEDASHBOARDSNODEGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteDashboardsNodeGroupRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.DeleteDashboardsNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.DeleteDashboardsNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.DeleteDashboardsNodeGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8093,
  serialized_end=8207,
)


_UPDATEDASHBOARDSNODEGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateDashboardsNodeGroupRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_group_spec', full_name='yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest.node_group_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8210,
  serialized_end=8461,
)


_DASHBOARDSNODEGROUPUPDATESPEC = _descriptor.Descriptor(
  name='DashboardsNodeGroupUpdateSpec',
  full_name='yandex.cloud.mdb.opensearch.v1.DashboardsNodeGroupUpdateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsNodeGroupUpdateSpec.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.mdb.opensearch.v1.DashboardsNodeGroupUpdateSpec.hosts_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8463,
  serialized_end=8577,
)


_ADDDASHBOARDSNODEGROUPREQUEST = _descriptor.Descriptor(
  name='AddDashboardsNodeGroupRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.AddDashboardsNodeGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.AddDashboardsNodeGroupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_group_spec', full_name='yandex.cloud.mdb.opensearch.v1.AddDashboardsNodeGroupRequest.node_group_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8580,
  serialized_end=8734,
)


_ADDNODEGROUPMETADATA = _descriptor.Descriptor(
  name='AddNodeGroupMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.AddNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.AddNodeGroupMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.AddNodeGroupMetadata.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8736,
  serialized_end=8792,
)


_UPDATENODEGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateNodeGroupMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateNodeGroupMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.UpdateNodeGroupMetadata.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8794,
  serialized_end=8853,
)


_DELETENODEGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteNodeGroupMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.DeleteNodeGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.DeleteNodeGroupMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.opensearch.v1.DeleteNodeGroupMetadata.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8855,
  serialized_end=8914,
)


_GETAUTHSETTINGSREQUEST = _descriptor.Descriptor(
  name='GetAuthSettingsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.GetAuthSettingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.GetAuthSettingsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8916,
  serialized_end=8974,
)


_UPDATEAUTHSETTINGSREQUEST = _descriptor.Descriptor(
  name='UpdateAuthSettingsRequest',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8976,
  serialized_end=9101,
)


_UPDATEAUTHSETTINGSMETADATA = _descriptor.Descriptor(
  name='UpdateAuthSettingsMetadata',
  full_name='yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9103,
  serialized_end=9151,
)

_LISTCLUSTERSRESPONSE.fields_by_name['clusters'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._CLUSTER
_CREATECLUSTERREQUEST_LABELSENTRY.containing_type = _CREATECLUSTERREQUEST
_CREATECLUSTERREQUEST.fields_by_name['labels'].message_type = _CREATECLUSTERREQUEST_LABELSENTRY
_CREATECLUSTERREQUEST.fields_by_name['environment'].enum_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._CLUSTER_ENVIRONMENT
_CREATECLUSTERREQUEST.fields_by_name['config_spec'].message_type = _CONFIGCREATESPEC
_CREATECLUSTERREQUEST.fields_by_name['maintenance_window'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_maintenance__pb2._MAINTENANCEWINDOW
_UPDATECLUSTERREQUEST_LABELSENTRY.containing_type = _UPDATECLUSTERREQUEST
_UPDATECLUSTERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECLUSTERREQUEST.fields_by_name['labels'].message_type = _UPDATECLUSTERREQUEST_LABELSENTRY
_UPDATECLUSTERREQUEST.fields_by_name['config_spec'].message_type = _CONFIGUPDATESPEC
_UPDATECLUSTERREQUEST.fields_by_name['maintenance_window'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_maintenance__pb2._MAINTENANCEWINDOW
_LISTCLUSTERLOGSREQUEST.fields_by_name['from_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCLUSTERLOGSREQUEST.fields_by_name['to_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCLUSTERLOGSREQUEST.fields_by_name['service_type'].enum_type = _LISTCLUSTERLOGSREQUEST_SERVICETYPE
_LISTCLUSTERLOGSREQUEST_SERVICETYPE.containing_type = _LISTCLUSTERLOGSREQUEST
_LOGRECORD_MESSAGEENTRY.containing_type = _LOGRECORD
_LOGRECORD.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGRECORD.fields_by_name['message'].message_type = _LOGRECORD_MESSAGEENTRY
_LISTCLUSTERLOGSRESPONSE.fields_by_name['logs'].message_type = _LOGRECORD
_STREAMLOGRECORD.fields_by_name['record'].message_type = _LOGRECORD
_STREAMCLUSTERLOGSREQUEST.fields_by_name['from_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCLUSTERLOGSREQUEST.fields_by_name['to_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCLUSTERLOGSREQUEST.fields_by_name['service_type'].enum_type = _STREAMCLUSTERLOGSREQUEST_SERVICETYPE
_STREAMCLUSTERLOGSREQUEST_SERVICETYPE.containing_type = _STREAMCLUSTERLOGSREQUEST
_LISTCLUSTEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTCLUSTERHOSTSRESPONSE.fields_by_name['hosts'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._HOST
_CONFIGCREATESPEC.fields_by_name['opensearch_spec'].message_type = _OPENSEARCHCREATESPEC
_CONFIGCREATESPEC.fields_by_name['dashboards_spec'].message_type = _DASHBOARDSCREATESPEC
_CONFIGCREATESPEC.fields_by_name['access'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._ACCESS
_OPENSEARCHCREATESPEC_NODEGROUP.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._RESOURCES
_OPENSEARCHCREATESPEC_NODEGROUP.fields_by_name['roles'].enum_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._OPENSEARCH_GROUPROLE
_OPENSEARCHCREATESPEC_NODEGROUP.containing_type = _OPENSEARCHCREATESPEC
_OPENSEARCHCREATESPEC.fields_by_name['node_groups'].message_type = _OPENSEARCHCREATESPEC_NODEGROUP
_DASHBOARDSCREATESPEC_NODEGROUP.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._RESOURCES
_DASHBOARDSCREATESPEC_NODEGROUP.containing_type = _DASHBOARDSCREATESPEC
_DASHBOARDSCREATESPEC.fields_by_name['node_groups'].message_type = _DASHBOARDSCREATESPEC_NODEGROUP
_CONFIGUPDATESPEC.fields_by_name['opensearch_spec'].message_type = _OPENSEARCHCLUSTERUPDATESPEC
_CONFIGUPDATESPEC.fields_by_name['dashboards_spec'].message_type = _DASHBOARDSCLUSTERUPDATESPEC
_CONFIGUPDATESPEC.fields_by_name['access'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._ACCESS
_RESTORECLUSTERREQUEST_LABELSENTRY.containing_type = _RESTORECLUSTERREQUEST
_RESTORECLUSTERREQUEST.fields_by_name['labels'].message_type = _RESTORECLUSTERREQUEST_LABELSENTRY
_RESTORECLUSTERREQUEST.fields_by_name['environment'].enum_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._CLUSTER_ENVIRONMENT
_RESTORECLUSTERREQUEST.fields_by_name['config_spec'].message_type = _CONFIGCREATESPEC
_RESTORECLUSTERREQUEST.fields_by_name['maintenance_window'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_maintenance__pb2._MAINTENANCEWINDOW
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type'].enum_type = _RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['delayed_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE.containing_type = _RESCHEDULEMAINTENANCEREQUEST
_RESCHEDULEMAINTENANCEMETADATA.fields_by_name['delayed_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCLUSTERBACKUPSRESPONSE.fields_by_name['backups'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2._BACKUP
_UPDATEOPENSEARCHNODEGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEOPENSEARCHNODEGROUPREQUEST.fields_by_name['node_group_spec'].message_type = _OPENSEARCHNODEGROUPUPDATESPEC
_OPENSEARCHNODEGROUPUPDATESPEC.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._RESOURCES
_OPENSEARCHNODEGROUPUPDATESPEC.fields_by_name['roles'].enum_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._OPENSEARCH_GROUPROLE
_ADDOPENSEARCHNODEGROUPREQUEST.fields_by_name['node_group_spec'].message_type = _OPENSEARCHCREATESPEC_NODEGROUP
_UPDATEDASHBOARDSNODEGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEDASHBOARDSNODEGROUPREQUEST.fields_by_name['node_group_spec'].message_type = _DASHBOARDSNODEGROUPUPDATESPEC
_DASHBOARDSNODEGROUPUPDATESPEC.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._RESOURCES
_ADDDASHBOARDSNODEGROUPREQUEST.fields_by_name['node_group_spec'].message_type = _DASHBOARDSCREATESPEC_NODEGROUP
_UPDATEAUTHSETTINGSREQUEST.fields_by_name['settings'].message_type = yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_auth__pb2._AUTHSETTINGS
DESCRIPTOR.message_types_by_name['GetClusterRequest'] = _GETCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateClusterRequest'] = _CREATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateClusterMetadata'] = _CREATECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterMetadata'] = _UPDATECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterMetadata'] = _DELETECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['ListClusterLogsRequest'] = _LISTCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['LogRecord'] = _LOGRECORD
DESCRIPTOR.message_types_by_name['ListClusterLogsResponse'] = _LISTCLUSTERLOGSRESPONSE
DESCRIPTOR.message_types_by_name['StreamLogRecord'] = _STREAMLOGRECORD
DESCRIPTOR.message_types_by_name['StreamClusterLogsRequest'] = _STREAMCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterOperationsRequest'] = _LISTCLUSTEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterOperationsResponse'] = _LISTCLUSTEROPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListClusterHostsRequest'] = _LISTCLUSTERHOSTSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterHostsResponse'] = _LISTCLUSTERHOSTSRESPONSE
DESCRIPTOR.message_types_by_name['MoveClusterRequest'] = _MOVECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['MoveClusterMetadata'] = _MOVECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['StartClusterRequest'] = _STARTCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['StartClusterMetadata'] = _STARTCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['StopClusterRequest'] = _STOPCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['StopClusterMetadata'] = _STOPCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['ConfigCreateSpec'] = _CONFIGCREATESPEC
DESCRIPTOR.message_types_by_name['OpenSearchCreateSpec'] = _OPENSEARCHCREATESPEC
DESCRIPTOR.message_types_by_name['DashboardsCreateSpec'] = _DASHBOARDSCREATESPEC
DESCRIPTOR.message_types_by_name['ConfigUpdateSpec'] = _CONFIGUPDATESPEC
DESCRIPTOR.message_types_by_name['OpenSearchClusterUpdateSpec'] = _OPENSEARCHCLUSTERUPDATESPEC
DESCRIPTOR.message_types_by_name['DashboardsClusterUpdateSpec'] = _DASHBOARDSCLUSTERUPDATESPEC
DESCRIPTOR.message_types_by_name['BackupClusterRequest'] = _BACKUPCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['BackupClusterMetadata'] = _BACKUPCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['RestoreClusterRequest'] = _RESTORECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['RestoreClusterMetadata'] = _RESTORECLUSTERMETADATA
DESCRIPTOR.message_types_by_name['RescheduleMaintenanceRequest'] = _RESCHEDULEMAINTENANCEREQUEST
DESCRIPTOR.message_types_by_name['RescheduleMaintenanceMetadata'] = _RESCHEDULEMAINTENANCEMETADATA
DESCRIPTOR.message_types_by_name['ListClusterBackupsRequest'] = _LISTCLUSTERBACKUPSREQUEST
DESCRIPTOR.message_types_by_name['ListClusterBackupsResponse'] = _LISTCLUSTERBACKUPSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteOpenSearchNodeGroupRequest'] = _DELETEOPENSEARCHNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateOpenSearchNodeGroupRequest'] = _UPDATEOPENSEARCHNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['OpenSearchNodeGroupUpdateSpec'] = _OPENSEARCHNODEGROUPUPDATESPEC
DESCRIPTOR.message_types_by_name['AddOpenSearchNodeGroupRequest'] = _ADDOPENSEARCHNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteDashboardsNodeGroupRequest'] = _DELETEDASHBOARDSNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateDashboardsNodeGroupRequest'] = _UPDATEDASHBOARDSNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['DashboardsNodeGroupUpdateSpec'] = _DASHBOARDSNODEGROUPUPDATESPEC
DESCRIPTOR.message_types_by_name['AddDashboardsNodeGroupRequest'] = _ADDDASHBOARDSNODEGROUPREQUEST
DESCRIPTOR.message_types_by_name['AddNodeGroupMetadata'] = _ADDNODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateNodeGroupMetadata'] = _UPDATENODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteNodeGroupMetadata'] = _DELETENODEGROUPMETADATA
DESCRIPTOR.message_types_by_name['GetAuthSettingsRequest'] = _GETAUTHSETTINGSREQUEST
DESCRIPTOR.message_types_by_name['UpdateAuthSettingsRequest'] = _UPDATEAUTHSETTINGSREQUEST
DESCRIPTOR.message_types_by_name['UpdateAuthSettingsMetadata'] = _UPDATEAUTHSETTINGSMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetClusterRequest = _reflection.GeneratedProtocolMessageType('GetClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.GetClusterRequest)
  })
_sym_db.RegisterMessage(GetClusterRequest)

ListClustersRequest = _reflection.GeneratedProtocolMessageType('ListClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClustersRequest)
  })
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType('ListClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClustersResponse)
  })
_sym_db.RegisterMessage(ListClustersResponse)

CreateClusterRequest = _reflection.GeneratedProtocolMessageType('CreateClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.CreateClusterRequest)
  })
_sym_db.RegisterMessage(CreateClusterRequest)
_sym_db.RegisterMessage(CreateClusterRequest.LabelsEntry)

CreateClusterMetadata = _reflection.GeneratedProtocolMessageType('CreateClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.CreateClusterMetadata)
  })
_sym_db.RegisterMessage(CreateClusterMetadata)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest)
  })
_sym_db.RegisterMessage(UpdateClusterRequest)
_sym_db.RegisterMessage(UpdateClusterRequest.LabelsEntry)

UpdateClusterMetadata = _reflection.GeneratedProtocolMessageType('UpdateClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateClusterMetadata)
  })
_sym_db.RegisterMessage(UpdateClusterMetadata)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DeleteClusterRequest)
  })
_sym_db.RegisterMessage(DeleteClusterRequest)

DeleteClusterMetadata = _reflection.GeneratedProtocolMessageType('DeleteClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DeleteClusterMetadata)
  })
_sym_db.RegisterMessage(DeleteClusterMetadata)

ListClusterLogsRequest = _reflection.GeneratedProtocolMessageType('ListClusterLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERLOGSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest)
  })
_sym_db.RegisterMessage(ListClusterLogsRequest)

LogRecord = _reflection.GeneratedProtocolMessageType('LogRecord', (_message.Message,), {

  'MessageEntry' : _reflection.GeneratedProtocolMessageType('MessageEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGRECORD_MESSAGEENTRY,
    '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.LogRecord.MessageEntry)
    })
  ,
  'DESCRIPTOR' : _LOGRECORD,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.LogRecord)
  })
_sym_db.RegisterMessage(LogRecord)
_sym_db.RegisterMessage(LogRecord.MessageEntry)

ListClusterLogsResponse = _reflection.GeneratedProtocolMessageType('ListClusterLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERLOGSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterLogsResponse)
  })
_sym_db.RegisterMessage(ListClusterLogsResponse)

StreamLogRecord = _reflection.GeneratedProtocolMessageType('StreamLogRecord', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLOGRECORD,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.StreamLogRecord)
  })
_sym_db.RegisterMessage(StreamLogRecord)

StreamClusterLogsRequest = _reflection.GeneratedProtocolMessageType('StreamClusterLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCLUSTERLOGSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest)
  })
_sym_db.RegisterMessage(StreamClusterLogsRequest)

ListClusterOperationsRequest = _reflection.GeneratedProtocolMessageType('ListClusterOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest)
  })
_sym_db.RegisterMessage(ListClusterOperationsRequest)

ListClusterOperationsResponse = _reflection.GeneratedProtocolMessageType('ListClusterOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterOperationsResponse)
  })
_sym_db.RegisterMessage(ListClusterOperationsResponse)

ListClusterHostsRequest = _reflection.GeneratedProtocolMessageType('ListClusterHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERHOSTSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest)
  })
_sym_db.RegisterMessage(ListClusterHostsRequest)

ListClusterHostsResponse = _reflection.GeneratedProtocolMessageType('ListClusterHostsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERHOSTSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterHostsResponse)
  })
_sym_db.RegisterMessage(ListClusterHostsResponse)

MoveClusterRequest = _reflection.GeneratedProtocolMessageType('MoveClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.MoveClusterRequest)
  })
_sym_db.RegisterMessage(MoveClusterRequest)

MoveClusterMetadata = _reflection.GeneratedProtocolMessageType('MoveClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.MoveClusterMetadata)
  })
_sym_db.RegisterMessage(MoveClusterMetadata)

StartClusterRequest = _reflection.GeneratedProtocolMessageType('StartClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.StartClusterRequest)
  })
_sym_db.RegisterMessage(StartClusterRequest)

StartClusterMetadata = _reflection.GeneratedProtocolMessageType('StartClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STARTCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.StartClusterMetadata)
  })
_sym_db.RegisterMessage(StartClusterMetadata)

StopClusterRequest = _reflection.GeneratedProtocolMessageType('StopClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.StopClusterRequest)
  })
_sym_db.RegisterMessage(StopClusterRequest)

StopClusterMetadata = _reflection.GeneratedProtocolMessageType('StopClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.StopClusterMetadata)
  })
_sym_db.RegisterMessage(StopClusterMetadata)

ConfigCreateSpec = _reflection.GeneratedProtocolMessageType('ConfigCreateSpec', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGCREATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ConfigCreateSpec)
  })
_sym_db.RegisterMessage(ConfigCreateSpec)

OpenSearchCreateSpec = _reflection.GeneratedProtocolMessageType('OpenSearchCreateSpec', (_message.Message,), {

  'NodeGroup' : _reflection.GeneratedProtocolMessageType('NodeGroup', (_message.Message,), {
    'DESCRIPTOR' : _OPENSEARCHCREATESPEC_NODEGROUP,
    '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup)
    })
  ,
  'DESCRIPTOR' : _OPENSEARCHCREATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec)
  })
_sym_db.RegisterMessage(OpenSearchCreateSpec)
_sym_db.RegisterMessage(OpenSearchCreateSpec.NodeGroup)

DashboardsCreateSpec = _reflection.GeneratedProtocolMessageType('DashboardsCreateSpec', (_message.Message,), {

  'NodeGroup' : _reflection.GeneratedProtocolMessageType('NodeGroup', (_message.Message,), {
    'DESCRIPTOR' : _DASHBOARDSCREATESPEC_NODEGROUP,
    '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup)
    })
  ,
  'DESCRIPTOR' : _DASHBOARDSCREATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec)
  })
_sym_db.RegisterMessage(DashboardsCreateSpec)
_sym_db.RegisterMessage(DashboardsCreateSpec.NodeGroup)

ConfigUpdateSpec = _reflection.GeneratedProtocolMessageType('ConfigUpdateSpec', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUPDATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec)
  })
_sym_db.RegisterMessage(ConfigUpdateSpec)

OpenSearchClusterUpdateSpec = _reflection.GeneratedProtocolMessageType('OpenSearchClusterUpdateSpec', (_message.Message,), {
  'DESCRIPTOR' : _OPENSEARCHCLUSTERUPDATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.OpenSearchClusterUpdateSpec)
  })
_sym_db.RegisterMessage(OpenSearchClusterUpdateSpec)

DashboardsClusterUpdateSpec = _reflection.GeneratedProtocolMessageType('DashboardsClusterUpdateSpec', (_message.Message,), {
  'DESCRIPTOR' : _DASHBOARDSCLUSTERUPDATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DashboardsClusterUpdateSpec)
  })
_sym_db.RegisterMessage(DashboardsClusterUpdateSpec)

BackupClusterRequest = _reflection.GeneratedProtocolMessageType('BackupClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.BackupClusterRequest)
  })
_sym_db.RegisterMessage(BackupClusterRequest)

BackupClusterMetadata = _reflection.GeneratedProtocolMessageType('BackupClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.BackupClusterMetadata)
  })
_sym_db.RegisterMessage(BackupClusterMetadata)

RestoreClusterRequest = _reflection.GeneratedProtocolMessageType('RestoreClusterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESTORECLUSTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _RESTORECLUSTERREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest)
  })
_sym_db.RegisterMessage(RestoreClusterRequest)
_sym_db.RegisterMessage(RestoreClusterRequest.LabelsEntry)

RestoreClusterMetadata = _reflection.GeneratedProtocolMessageType('RestoreClusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESTORECLUSTERMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.RestoreClusterMetadata)
  })
_sym_db.RegisterMessage(RestoreClusterMetadata)

RescheduleMaintenanceRequest = _reflection.GeneratedProtocolMessageType('RescheduleMaintenanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESCHEDULEMAINTENANCEREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest)
  })
_sym_db.RegisterMessage(RescheduleMaintenanceRequest)

RescheduleMaintenanceMetadata = _reflection.GeneratedProtocolMessageType('RescheduleMaintenanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESCHEDULEMAINTENANCEMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceMetadata)
  })
_sym_db.RegisterMessage(RescheduleMaintenanceMetadata)

ListClusterBackupsRequest = _reflection.GeneratedProtocolMessageType('ListClusterBackupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERBACKUPSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest)
  })
_sym_db.RegisterMessage(ListClusterBackupsRequest)

ListClusterBackupsResponse = _reflection.GeneratedProtocolMessageType('ListClusterBackupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERBACKUPSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.ListClusterBackupsResponse)
  })
_sym_db.RegisterMessage(ListClusterBackupsResponse)

DeleteOpenSearchNodeGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteOpenSearchNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOPENSEARCHNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DeleteOpenSearchNodeGroupRequest)
  })
_sym_db.RegisterMessage(DeleteOpenSearchNodeGroupRequest)

UpdateOpenSearchNodeGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateOpenSearchNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOPENSEARCHNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest)
  })
_sym_db.RegisterMessage(UpdateOpenSearchNodeGroupRequest)

OpenSearchNodeGroupUpdateSpec = _reflection.GeneratedProtocolMessageType('OpenSearchNodeGroupUpdateSpec', (_message.Message,), {
  'DESCRIPTOR' : _OPENSEARCHNODEGROUPUPDATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec)
  })
_sym_db.RegisterMessage(OpenSearchNodeGroupUpdateSpec)

AddOpenSearchNodeGroupRequest = _reflection.GeneratedProtocolMessageType('AddOpenSearchNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDOPENSEARCHNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.AddOpenSearchNodeGroupRequest)
  })
_sym_db.RegisterMessage(AddOpenSearchNodeGroupRequest)

DeleteDashboardsNodeGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteDashboardsNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDASHBOARDSNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DeleteDashboardsNodeGroupRequest)
  })
_sym_db.RegisterMessage(DeleteDashboardsNodeGroupRequest)

UpdateDashboardsNodeGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateDashboardsNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDASHBOARDSNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest)
  })
_sym_db.RegisterMessage(UpdateDashboardsNodeGroupRequest)

DashboardsNodeGroupUpdateSpec = _reflection.GeneratedProtocolMessageType('DashboardsNodeGroupUpdateSpec', (_message.Message,), {
  'DESCRIPTOR' : _DASHBOARDSNODEGROUPUPDATESPEC,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DashboardsNodeGroupUpdateSpec)
  })
_sym_db.RegisterMessage(DashboardsNodeGroupUpdateSpec)

AddDashboardsNodeGroupRequest = _reflection.GeneratedProtocolMessageType('AddDashboardsNodeGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDDASHBOARDSNODEGROUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.AddDashboardsNodeGroupRequest)
  })
_sym_db.RegisterMessage(AddDashboardsNodeGroupRequest)

AddNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('AddNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDNODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.AddNodeGroupMetadata)
  })
_sym_db.RegisterMessage(AddNodeGroupMetadata)

UpdateNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateNodeGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateNodeGroupMetadata)

DeleteNodeGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteNodeGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETENODEGROUPMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.DeleteNodeGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteNodeGroupMetadata)

GetAuthSettingsRequest = _reflection.GeneratedProtocolMessageType('GetAuthSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHSETTINGSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.GetAuthSettingsRequest)
  })
_sym_db.RegisterMessage(GetAuthSettingsRequest)

UpdateAuthSettingsRequest = _reflection.GeneratedProtocolMessageType('UpdateAuthSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTHSETTINGSREQUEST,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsRequest)
  })
_sym_db.RegisterMessage(UpdateAuthSettingsRequest)

UpdateAuthSettingsMetadata = _reflection.GeneratedProtocolMessageType('UpdateAuthSettingsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAUTHSETTINGSMETADATA,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsMetadata)
  })
_sym_db.RegisterMessage(UpdateAuthSettingsMetadata)


DESCRIPTOR._options = None
_GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
_CREATECLUSTERREQUEST_LABELSENTRY._options = None
_CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
_CREATECLUSTERREQUEST.fields_by_name['name']._options = None
_CREATECLUSTERREQUEST.fields_by_name['description']._options = None
_CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
_CREATECLUSTERREQUEST.fields_by_name['config_spec']._options = None
_CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
_UPDATECLUSTERREQUEST_LABELSENTRY._options = None
_UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
_DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
_LOGRECORD_MESSAGEENTRY._options = None
_STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
_STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._options = None
_STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
_LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
_MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
_STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_CONFIGCREATESPEC.fields_by_name['admin_password']._options = None
_OPENSEARCHCREATESPEC_NODEGROUP.fields_by_name['name']._options = None
_OPENSEARCHCREATESPEC_NODEGROUP.fields_by_name['hosts_count']._options = None
_OPENSEARCHCREATESPEC_NODEGROUP.fields_by_name['zone_ids']._options = None
_OPENSEARCHCREATESPEC_NODEGROUP.fields_by_name['subnet_ids']._options = None
_DASHBOARDSCREATESPEC_NODEGROUP.fields_by_name['name']._options = None
_DASHBOARDSCREATESPEC_NODEGROUP.fields_by_name['hosts_count']._options = None
_DASHBOARDSCREATESPEC_NODEGROUP.fields_by_name['subnet_ids']._options = None
_CONFIGUPDATESPEC.fields_by_name['admin_password']._options = None
_BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_RESTORECLUSTERREQUEST_LABELSENTRY._options = None
_RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['name']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['description']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['labels']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['config_spec']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['network_id']._options = None
_RESTORECLUSTERREQUEST.fields_by_name['folder_id']._options = None
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._options = None
_RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._options = None
_LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._options = None
_LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._options = None
_DELETEOPENSEARCHNODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEOPENSEARCHNODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEOPENSEARCHNODEGROUPREQUEST.fields_by_name['name']._options = None
_ADDOPENSEARCHNODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_DELETEDASHBOARDSNODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_DELETEDASHBOARDSNODEGROUPREQUEST.fields_by_name['name']._options = None
_UPDATEDASHBOARDSNODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEDASHBOARDSNODEGROUPREQUEST.fields_by_name['name']._options = None
_ADDDASHBOARDSNODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
_GETAUTHSETTINGSREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEAUTHSETTINGSREQUEST.fields_by_name['cluster_id']._options = None

_CLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='ClusterService',
  full_name='yandex.cloud.mdb.opensearch.v1.ClusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=9154,
  serialized_end=14228,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2._CLUSTER,
    serialized_options=b'\202\323\344\223\002.\022,/managed-opensearch/v1/clusters/{cluster_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCLUSTERSREQUEST,
    output_type=_LISTCLUSTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/managed-opensearch/v1/clusters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$\"\037/managed-opensearch/v1/clusters:\001*\262\322* \n\025CreateClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\00212,/managed-opensearch/v1/clusters/{cluster_id}:\001*\262\322* \n\025UpdateClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.*,/managed-opensearch/v1/clusters/{cluster_id}\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Backup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Backup',
    index=5,
    containing_service=None,
    input_type=_BACKUPCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0025\"3/managed-opensearch/v1/clusters/{cluster_id}:backup\262\322* \n\025BackupClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Restore',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Restore',
    index=6,
    containing_service=None,
    input_type=_RESTORECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002,\"\'/managed-opensearch/v1/clusters:restore:\001*\262\322*!\n\026RestoreClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RescheduleMaintenance',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.RescheduleMaintenance',
    index=7,
    containing_service=None,
    input_type=_RESCHEDULEMAINTENANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002G\"B/managed-opensearch/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListBackups',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.ListBackups',
    index=8,
    containing_service=None,
    input_type=_LISTCLUSTERBACKUPSREQUEST,
    output_type=_LISTCLUSTERBACKUPSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/managed-opensearch/v1/clusters/{cluster_id}/backups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Move',
    index=9,
    containing_service=None,
    input_type=_MOVECLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026\"1/managed-opensearch/v1/clusters/{cluster_id}:move:\001*\262\322*\036\n\023MoveClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Start',
    index=10,
    containing_service=None,
    input_type=_STARTCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0024\"2/managed-opensearch/v1/clusters/{cluster_id}:start\262\322*\037\n\024StartClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.Stop',
    index=11,
    containing_service=None,
    input_type=_STOPCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"1/managed-opensearch/v1/clusters/{cluster_id}:stop\262\322*\036\n\023StopClusterMetadata\022\007Cluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogs',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.ListLogs',
    index=12,
    containing_service=None,
    input_type=_LISTCLUSTERLOGSREQUEST,
    output_type=_LISTCLUSTERLOGSRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/managed-opensearch/v1/clusters/{cluster_id}:logs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamLogs',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.StreamLogs',
    index=13,
    containing_service=None,
    input_type=_STREAMCLUSTERLOGSREQUEST,
    output_type=_STREAMLOGRECORD,
    serialized_options=b'\202\323\344\223\002:\0228/managed-opensearch/v1/clusters/{cluster_id}:stream_logs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.ListOperations',
    index=14,
    containing_service=None,
    input_type=_LISTCLUSTEROPERATIONSREQUEST,
    output_type=_LISTCLUSTEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/managed-opensearch/v1/clusters/{cluster_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListHosts',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.ListHosts',
    index=15,
    containing_service=None,
    input_type=_LISTCLUSTERHOSTSREQUEST,
    output_type=_LISTCLUSTERHOSTSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/managed-opensearch/v1/clusters/{cluster_id}/hosts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddOpenSearchNodeGroup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.AddOpenSearchNodeGroup',
    index=16,
    containing_service=None,
    input_type=_ADDOPENSEARCHNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups:\001*\262\322*-\n\024AddNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOpenSearchNodeGroup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.DeleteOpenSearchNodeGroup',
    index=17,
    containing_service=None,
    input_type=_DELETEOPENSEARCHNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002L*J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateOpenSearchNodeGroup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.UpdateOpenSearchNodeGroup',
    index=18,
    containing_service=None,
    input_type=_UPDATEOPENSEARCHNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002O2J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}:\001*\262\322*0\n\027UpdateNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddDashboardsNodeGroup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.AddDashboardsNodeGroup',
    index=19,
    containing_service=None,
    input_type=_ADDDASHBOARDSNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups:\001*\262\322*-\n\024AddNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDashboardsNodeGroup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.DeleteDashboardsNodeGroup',
    index=20,
    containing_service=None,
    input_type=_DELETEDASHBOARDSNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002L*J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDashboardsNodeGroup',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.UpdateDashboardsNodeGroup',
    index=21,
    containing_service=None,
    input_type=_UPDATEDASHBOARDSNODEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002O2J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}:\001*\262\322*0\n\027UpdateNodeGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthSettings',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.GetAuthSettings',
    index=22,
    containing_service=None,
    input_type=_GETAUTHSETTINGSREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_auth__pb2._AUTHSETTINGS,
    serialized_options=b'\202\323\344\223\0023\0221/managed-opensearch/v1/clusters/{cluster_id}/auth',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAuthSettings',
    full_name='yandex.cloud.mdb.opensearch.v1.ClusterService.UpdateAuthSettings',
    index=23,
    containing_service=None,
    input_type=_UPDATEAUTHSETTINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026\0321/managed-opensearch/v1/clusters/{cluster_id}/auth:\001*\262\322**\n\032UpdateAuthSettingsMetadata\022\014AuthSettings',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLUSTERSERVICE)

DESCRIPTOR.services_by_name['ClusterService'] = _CLUSTERSERVICE

# @@protoc_insertion_point(module_scope)
